@@ -3,7 +3,7 @@ from multiprocessing import Pool
 from tqdm import tqdm
 import pandas as pd
 
-nlp = spacy.load("en_core_web_sm")
+nlp = spacy.load("fr_core_news_lg")
 
 
 def get_sent(text):
@@ -12,14 +12,14 @@ def get_sent(text):
     return res
 
 
+def sent_extract(docs):
+    res = list(tqdm(map(get_sent, docs), total=len(docs)))
+
+    return res
+
+
 def sent_multiprocessing(docs):
     with Pool(8) as p:
         res = list(tqdm(p.imap(get_sent, docs), total=len(docs)))
 
     return res
-
-
-def sent_extract(docs):
-    res = list(tqdm(map(get_sent, docs), total=len(docs)))
-
-    return res
